==> kotlin-compiler-0.10.709-sources.jar: org/jetbrains/kotlin/js/inline/util/rewriters/NameReplacingVisitor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.js.inline.util.rewriters

import com.google.dart.compiler.backend.js.ast.JsVisitorWithContextImpl
import com.google.dart.compiler.backend.js.ast.JsName
import com.google.dart.compiler.backend.js.ast.JsExpression
import com.google.dart.compiler.backend.js.ast.JsNameRef
import com.google.dart.compiler.backend.js.ast.JsContext
import com.google.dart.compiler.backend.js.ast.JsVars
import com.google.dart.compiler.backend.js.ast.HasName
import com.google.dart.compiler.backend.js.ast.JsLabel

class NameReplacingVisitor(private val replaceMap: Map<JsName, JsExpression>) : JsVisitorWithContextImpl() {

    override fun endVisit(x: JsNameRef?, ctx: JsContext?) {
        if (x == null || ctx == null) return

        val replacement = replaceMap[x.getName()]
        if (replacement == null) return

        ctx.replaceMe(replacement)
    }

    override fun endVisit(x: JsVars.JsVar?, ctx: JsContext?) {
        if (x == null || ctx == null) return

        val replacement = replaceMap[x.getName()]
        if (replacement is HasName) {
            val replacementVar = JsVars.JsVar(replacement.getName(), x.getInitExpression())
            ctx.replaceMe(replacementVar)
        }
    }

    override fun endVisit(x: JsLabel?, ctx: JsContext?) {
        if (x == null || ctx == null) return

        val replacement = replaceMap[x.getName()]
        if (replacement is HasName) {
            val replacementLabel = JsLabel(replacement.getName(), x.getStatement())
            ctx.replaceMe(replacementLabel)
        }
    }
}

==> kotlin-compiler-0.12.613-sources.jar: org/jetbrains/kotlin/js/inline/util/rewriters/NameReplacingVisitor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.js.inline.util.rewriters

import com.google.dart.compiler.backend.js.ast.JsVisitorWithContextImpl
import com.google.dart.compiler.backend.js.ast.JsName
import com.google.dart.compiler.backend.js.ast.JsExpression
import com.google.dart.compiler.backend.js.ast.JsNameRef
import com.google.dart.compiler.backend.js.ast.JsContext
import com.google.dart.compiler.backend.js.ast.JsVars
import com.google.dart.compiler.backend.js.ast.HasName
import com.google.dart.compiler.backend.js.ast.JsLabel

class NameReplacingVisitor(private val replaceMap: Map<JsName, JsExpression>) : JsVisitorWithContextImpl() {

    override fun endVisit(x: JsNameRef, ctx: JsContext<*>) {
        val replacement = replaceMap[x.getName()]
        if (replacement == null) return

        ctx.replaceMe(replacement)
    }

    override fun endVisit(x: JsVars.JsVar, ctx: JsContext<*>) {
        val replacement = replaceMap[x.getName()]
        if (replacement is HasName) {
            val replacementVar = JsVars.JsVar(replacement.getName(), x.getInitExpression())
            ctx.replaceMe(replacementVar)
        }
    }

    override fun endVisit(x: JsLabel, ctx: JsContext<*>) {
        val replacement = replaceMap[x.getName()]
        if (replacement is HasName) {
            val replacementLabel = JsLabel(replacement.getName(), x.getStatement())
            ctx.replaceMe(replacementLabel)
        }
    }
}
